.. include:: warning.rst

.. _cwprops:

The property mecanism
---------------------

.. TODO XXX CWProperty and co


Property API
~~~~~~~~~~~~
.. TODO XXX feed me

Registering and using your own property
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. TODO XXX feed me
